powered by
This function calculates the geodesic of a point to multiple points given the coordinate information. It is a wrapper of geodist::geodist_vec().
geodist::geodist_vec()
dist_point_to_vector(plon, plat, vlon, vlat)
Numeric. The geodesic of a point to multiple points in meters.
Numeric. The longitude of a point.
Numeric. The latitude of a point.
Numeric. A vector of longitude values.
Numeric. A vector of latitude values.
# Define vlon and vlat vlon <- c(141.12, 141.13) vlat <- c(-37.1, -37.0) # Calculate the geodesic dist_point_to_vector(141.12, -37.1, vlon, vlat)
Run the code above in your browser using DataLab